@@ -36,6 +36,8 @@
 #define GCERR_NEGATIVE_VERB_MISMATCH 13
 #define GCERR_A_INFINITIVE_REQUIRED 14
 #define GCERR_MA_INFINITIVE_REQUIRED 15
+#define GCERR_MISPLACED_SIDESANA 16
+#define GCERR_MISSING_MAIN_VERB 17
 
 namespace libvoikko {
 
