@@ -17,6 +17,7 @@
  *********************************************************************************/
 
 #include <cstring>
+#include <set>
 #include "setup/Dictionary.hpp"
 #include "setup/DictionaryLoader.hpp"
 #include "porting.h"
@@ -49,11 +50,11 @@ VOIKKOEXPORT void voikko_free_dicts(voikko_dict ** dicts) {
 }
 
 VOIKKOEXPORT const char * voikko_dict_language(const voikko_dict * dict) {
-	return "fi"; // for now
+	return dict->getLanguage().getLanguage().c_str();
 }
 
 VOIKKOEXPORT const char * voikko_dict_variant(const voikko_dict * dict) {
-	return dict->getVariant().c_str();
+	return dict->getLanguage().getPrivateUse().c_str();
 }
 
 VOIKKOEXPORT const char * voikko_dict_description(const voikko_dict * dict) {
@@ -64,20 +65,29 @@ VOIKKOEXPORT char ** voikkoListSupportedSpellingLanguages(const char * path) {
 	list<Dictionary> dictList = path ?
 	                            DictionaryLoader::findAllAvailable(path) :
 	                            DictionaryLoader::findAllAvailable();
-	// for now we assume all dictionaries to be for Finnish
-	bool hasDict = !dictList.empty();
-	if (hasDict) {
-		char ** languages = new char*[2];
-		languages[0] = new char[3];
-		strcpy(languages[0], "fi");
-		languages[1] = 0;
-		return languages;
-	} else {
-		char ** languages = new char*[1];
-		languages[0] = 0;
-		return languages;
+	set<string> allLanguages;
+	for (list<Dictionary>::iterator i = dictList.begin(); i != dictList.end(); ++i) {
+		allLanguages.insert((*i).getLanguage().getLanguage());
 	}
+	
+	char ** languages = new char*[allLanguages.size() + 1];
+	size_t n = 0;
+	for (set<string>::iterator i = allLanguages.begin(); i != allLanguages.end(); ++i) {
+		string lang = *i;
+		languages[n] = new char[lang.size() + 1];
+		strcpy(languages[n], lang.c_str());
+		n++;
+	}
+	languages[n] = 0;
+	return languages;
 }
 
+VOIKKOEXPORT const char * voikkoGetVersion() {
+	#ifdef PACKAGE_VERSION
+		return PACKAGE_VERSION;
+	#else
+		return "(unknown)";
+	#endif
+}
 
 } }
