@@ -19,6 +19,10 @@
 #ifndef VOIKKO_SETUP_SETUP_H
 #define VOIKKO_SETUP_SETUP_H
 
+#if HAVE_CONFIG_H
+#  include <config.h>
+#endif
+
 #include "morphology/Analyzer.hpp"
 #include "spellchecker/Speller.hpp"
 #include "spellchecker/SpellerCache.hpp"
@@ -27,6 +31,11 @@
 #include "setup/Dictionary.hpp"
 #include "grammar/GcCache.hpp"
 
+// TODO proper abstraction
+namespace hfst_ol {
+	class ZHfstOspeller;
+}
+
 namespace libvoikko {
 
 typedef struct {
@@ -48,6 +57,7 @@ typedef struct {
 	spellchecker::suggestion::SuggestionGenerator * suggestionGenerator;
 	hyphenator::Hyphenator * hyphenator;
 	setup::Dictionary dictionary;
+	hfst_ol::ZHfstOspeller* hfst;
 } voikko_options_t;
 
 }
