@@ -1,5 +1,5 @@
 /* Libvoikko: Finnish spellchecker and hyphenator library
- * Copyright (C) 2006 - 2009 Harri Pitkänen <hatapitk@iki.fi>
+ * Copyright (C) 2006 - 2010 Harri Pitkänen <hatapitk@iki.fi>
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -16,23 +16,17 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
  *********************************************************************************/
 
-#include "voikko_defs.h"
+#include "porting.h"
 #include "setup/setup.hpp"
 #include "utils/utils.hpp"
 #include "utils/StringUtils.hpp"
 #include "character/charset.hpp"
-#include "spellchecker/spell.hpp"
-#include "spellchecker/suggestion/SuggestionGeneratorCaseChange.hpp"
-#include "spellchecker/suggestion/SuggestionStrategy.hpp"
-#include "spellchecker/suggestion/SuggestionStrategyOcr.hpp"
-#include "spellchecker/suggestion/SuggestionStrategyTyping.hpp"
-#include <cstdlib>
+#include "spellchecker/suggestion/SuggestionStatus.hpp"
+#include "spellchecker/suggestion/SuggestionGenerator.hpp"
 #include <cstring>
-#include <wchar.h>
-#include <wctype.h>
+#include <cwchar>
 
 #define MAX_SUGGESTIONS 5
-#define COST_LIMIT 350
 
 using namespace libvoikko::spellchecker::suggestion;
 
@@ -69,35 +63,30 @@ VOIKKOEXPORT void voikko_free_suggest_ucs4(wchar_t ** suggest_result) {
 	}
 }
 
-VOIKKOEXPORT void voikko_free_suggest_cstr(char ** suggest_result) {
-	// C deallocation is used here to maintain compatibility with some
-	// broken applications before libvoikko 1.5.
+VOIKKOEXPORT void voikkoFreeCstrArray(char ** suggest_result) {
 	if (suggest_result) {
 		for (char ** p = suggest_result; *p; p++) {
-			free(*p);
+			delete[] *p;
 		}
-		free(suggest_result);
+		delete[] suggest_result;
 	}
 }
 
-VOIKKOEXPORT wchar_t ** voikko_suggest_ucs4(int handle, const wchar_t * word) {
+VOIKKOEXPORT wchar_t ** voikkoSuggestUcs4(voikko_options_t * options, const wchar_t * word) {
 	bool add_dots = false;
 	if (word == 0) return 0;
 	size_t wlen = wcslen(word);
 	if (wlen <= 1 || wlen > LIBVOIKKO_MAX_WORD_CHARS) return 0;
 	
-	ENTER_V
 	wchar_t * nword = voikko_normalise(word, wlen);
 	if (nword == 0) {
-		EXIT_V
 		return 0;
 	}
 	wlen = wcslen(nword);
 	
-	if (voikko_options.ignore_dot) {
+	if (options->ignore_dot) {
 		if (wlen == 2) {
 			delete[] nword;
-			EXIT_V
 			return 0;
 		}
 		if (nword[wlen-1] == L'.') {
@@ -106,35 +95,13 @@ VOIKKOEXPORT wchar_t ** voikko_suggest_ucs4(int handle, const wchar_t * word) {
 		}
 	}
 	
-	size_t maxCost = COST_LIMIT;
-	if (voikko_options.suggestion_type == ST_OCR) {
-		maxCost = maxCost * 3;
-	}
-	SuggestionStatus status(handle, nword, wlen, MAX_SUGGESTIONS * 3, maxCost);
+	SuggestionStatus status(nword, wlen, MAX_SUGGESTIONS * 3);
 	
-	SuggestionGeneratorCaseChange caseChanger;
-	caseChanger.generate(&status);
-	if (status.getSuggestionCount() > 0) {
-		delete[] nword;
-		EXIT_V
-		return getSuggestions(status, add_dots);
-	}
+	SuggestionGenerator * generator = options->suggestionGenerator;
+	generator->generate(&status);
 	
-	SuggestionStrategy * strategy = 0;
-	switch (voikko_options.suggestion_type) {
-		case ST_STD:
-			strategy = new SuggestionStrategyTyping();
-			break;
-		case ST_OCR:
-			strategy = new SuggestionStrategyOcr();
-			break;
-	}
-	strategy->generate(&status);
-	delete strategy;
-
 	if (status.getSuggestionCount() == 0) {
 		delete[] nword;
-		EXIT_V
 		return 0;
 	}
 	
@@ -171,21 +138,30 @@ VOIKKOEXPORT wchar_t ** voikko_suggest_ucs4(int handle, const wchar_t * word) {
 	}
 
 	delete[] nword;
-	EXIT_V
 	return suggestions;
 }
 
-VOIKKOEXPORT char ** voikko_suggest_cstr(int handle, const char * word) {
-	if (word == 0 || word[0] == '\0') return 0;
+VOIKKOEXPORT char ** voikkoSuggestCstr(voikko_options_t * options, const char * word) {
+	if (word == 0 || word[0] == '\0') {
+		return 0;
+	}
 	size_t len = strlen(word);
-	if (len > LIBVOIKKO_MAX_WORD_CHARS) return 0;
-	wchar_t * word_ucs4 = voikko_cstrtoucs4(word, voikko_options.encoding, len);
-	if (word_ucs4 == 0) return 0;
-	wchar_t ** suggestions_ucs4 = voikko_suggest_ucs4(handle, word_ucs4);
+	if (len > LIBVOIKKO_MAX_WORD_CHARS) {
+		return 0;
+	}
+	wchar_t * word_ucs4 = utils::StringUtils::ucs4FromUtf8(word, len);
+	if (word_ucs4 == 0) {
+		return 0;
+	}
+	wchar_t ** suggestions_ucs4 = voikkoSuggestUcs4(options, word_ucs4);
 	delete[] word_ucs4;
-	if (suggestions_ucs4 == 0) return 0;
+	if (suggestions_ucs4 == 0) {
+		return 0;
+	}
 	int scount = 0;
-	while (suggestions_ucs4[scount] != 0) scount++;
+	while (suggestions_ucs4[scount] != 0) {
+		scount++;
+	}
 	
 	char ** suggestions = new char*[scount + 1];
 	if (suggestions == 0) {
@@ -195,8 +171,10 @@ VOIKKOEXPORT char ** voikko_suggest_cstr(int handle, const char * word) {
 	
 	int j = 0;
 	for (int i = 0; i < scount; i++) {
-		char * suggestion = voikko_ucs4tocstr(suggestions_ucs4[i], voikko_options.encoding, 0);
-		if (suggestion == 0) continue; /* suggestion cannot be encoded */
+		char * suggestion = utils::StringUtils::utf8FromUcs4(suggestions_ucs4[i]);
+		if (suggestion == 0) {
+			continue; /* suggestion cannot be encoded */
+		}
 		suggestions[j++] = suggestion;
 	}
 	voikko_free_suggest_ucs4(suggestions_ucs4);
@@ -208,9 +186,6 @@ VOIKKOEXPORT char ** voikko_suggest_cstr(int handle, const char * word) {
 		suggestions[j] = 0;
 	}
 	
-	// Convert to C allocation to maintain compatibility with some
-	// broken applications before libvoikko 1.5.
-	utils::StringUtils::convertCStringArrayToMalloc(suggestions);
 	return suggestions;
 }
 
